@@ -423,7 +423,7 @@ class HttpClient(Client):
         Args:
             visibility (RoomVisibility): whether to have the room published in
                 the server's room directory or not.
-                Defaults to ``RoomVisibility.Private``.
+                Defaults to ``RoomVisibility.private``.
 
             alias (str, optional): The desired canonical alias local part.
                 For example, if set to "foo" and the room is created on the
