@@ -634,7 +634,9 @@ class Sas(olm.Sas):
 
     def receive_key_event(self, event):
         """Receive a KeyVerificationKey event."""
-        if self.other_key_set:
+        if (self.other_key_set or
+                ((self.state != SasState.started) and
+                 (self.state != SasState.accepted))):
             self.state = SasState.canceled
             (
                 self.cancel_code,
